==> albert_0.25.0.orig.tar.gz: albert-0.25.0/plugins/python/i18n/python.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ConfigWidget</name>
    <message>
        <location filename="../src/configwidget.ui" line="29"/>
        <source>The Python plugin makes the app extendable by Python modules. The built-in albert module exposes several functions and classes for use with Albert. The Python plugins are loaded from `&amp;lt;APPDATADIR&amp;gt;/python/plugins`.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/configwidget.ui" line="51"/>
        <source>Open user plugin dir</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/configwidget.ui" line="58"/>
        <source>Open stub file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/configwidget.ui" line="65"/>
        <source>Open site-packages</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../src/plugin.cpp" line="48"/>
        <source>Failed creating site-packages dir %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/plugin.cpp" line="54"/>
        <source>Failed creating writeable plugin dir %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PyPluginLoader</name>
    <message>
        <location filename="../src/pypluginloader.cpp" line="242"/>
        <source>Some modules in the plugin &apos;%1&apos; were not found.

Install dependencies into the virtual environment?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/pypluginloader.cpp" line="304"/>
        <source>No &apos;%1&apos; in $PATH.</source>
        <translation></translation>
    </message>
</context>
</TS>

==> albert_0.26.3.orig.tar.gz: albert-0.26.3/plugins/python/i18n/python.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>The Python plugin makes the app extendable by Python modules. The built-in albert module exposes several functions and classes for use with Albert. The Python plugins are loaded from `&amp;lt;APPDATADIR&amp;gt;/python/plugins`.</source>
        <translation></translation>
    </message>
    <message>
        <source>Open user plugin dir</source>
        <translation></translation>
    </message>
    <message>
        <source>Open stub file</source>
        <translation></translation>
    </message>
    <message>
        <source>Open site-packages</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Failed creating writeable plugin dir %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Failed initializing the interpreter: %1 %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Failed initializing virtual environment. Exit code: %1.</source>
        <translation></translation>
    </message>
    <message>
        <source>Some modules in the plugin &apos;%1&apos; were not found.

Install dependencies into the virtual environment?</source>
        <translation></translation>
    </message>
    <message>
        <source>No &apos;%1&apos; in $PATH.</source>
        <translation></translation>
    </message>
</context>
</TS>
